@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Text Trees
 #
-# Copyright (C) 2001-2022 NLTK Project
+# Copyright (C) 2001-2023 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Peter Ljunglöf <peter.ljunglof@gu.se>
@@ -16,7 +16,6 @@ syntax trees and morphological trees.
 """
 
 import re
-import sys
 
 from nltk.grammar import Nonterminal, Production
 from nltk.internals import deprecated
@@ -647,9 +646,9 @@ class Tree(list):
         open_b, close_b = brackets
         open_pattern, close_pattern = (re.escape(open_b), re.escape(close_b))
         if node_pattern is None:
-            node_pattern = fr"[^\s{open_pattern}{close_pattern}]+"
+            node_pattern = rf"[^\s{open_pattern}{close_pattern}]+"
         if leaf_pattern is None:
-            leaf_pattern = fr"[^\s{open_pattern}{close_pattern}]+"
+            leaf_pattern = rf"[^\s{open_pattern}{close_pattern}]+"
         token_re = re.compile(
             r"%s\s*(%s)?|%s|(%s)"
             % (open_pattern, node_pattern, close_pattern, leaf_pattern)
